@@ -2,7 +2,7 @@
 
 #' @title gp_cv
 #' @description Performs cross-validation to select an optimal tuning parameter for penalized MLE of the lengthscale parameter in Gaussian processes.
-#' @details This function supports both leave-one-out and k-fold cross-validation for selecting a suitable tuning parameter value in penalized likelihoood estimation.
+#' @details This function supports both leave-one-out and k-fold cross-validation for selecting a suitable tuning parameter value in penalized likelihood estimation.
 #'          Users can choose among several evaluation metrics, including decorrelated prediction error (dpe), Mahalanobis distance (md), score, and mean squared error (mse), to guide the selection process.
 #'          For the dpe, md, and score metrics, only k-fold cross-validation is available, as these metrics account for correlation structure. For leave-one-out cross-validation,
 #'          only the mse metric be used. For dpe, md, and mse metrics, the lambda corresponding to the minimum value across the k folds is selected as optimal. For the score metric, the lambda with the maximum value is selected.
@@ -140,11 +140,12 @@ gp_cv <- function(y, x, lambda=NULL, sep=TRUE, mu=FALSE, g=FALSE, fixed_g=NULL,
     # generate initial values
     initialvals <- random_init(d, param, n_init)
   } else { # initial values are specified but the number doesn't match to the parameters to estimate
-    if(profile & d!=length(initialvals)) {
+    if(is.null(dim(initialvals))) initialvals <- matrix(initialvals, ncol=1)
+    if(profile & d!=ncol(initialvals)) {
       stop("the length of initial values doesn't match")
     }
     if(!profile) {
-      n_init <- length(initialvals)
+      n_init <- ncol(initialvals)
       if (mu & g) {
         param <- 3 # theta and (s2 + mu + g)
       } else if (mu | g) {
